==> groupfolders-v19.1.5.tar.gz: groupfolders/l10n/sl.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Ne moreš odstraniti lastne pravice do branja.",
    "Team folders" : "Ekipne mape",
    "Admin configured folders shared with everyone in a team" : "Skrbnik je nastavil mape deljene z vsemi v ekipi",
    "Unset" : "Odstrani izbor",
    "Denied (Inherited permission)" : "Zavrnjeno (podedovano dovoljenje)",
    "Allowed (Inherited permission)" : "Dovoljeno (podedovano dovoljenje)",
    "Denied" : "Zavrnjeno",
    "Allowed" : "Dovoljeno",
    "Access denied" : "Dostop je zavrnjen",
    "Access allowed" : "Dostop dovoljen",
    "Inherit permission" : "Podeduj dovoljenje",
    "Deny" : "Zavrni",
    "Allow" : "Dovoli",
    "Group" : "Skupina",
    "Team" : "Skupina",
    "Team folder" : "Ekipna mapa",
    "Read" : "Branje",
    "Write" : "Zapiši",
    "Create" : "Ustvari",
    "Delete" : "Izbriši",
    "Share" : "Omogoči souporabo",
    "You" : "· Jaz",
    "Remove access rule" : "Odstrani pravilo za dostop",
    "Add advanced permission rule" : "Dodaj napredno pravilo dovoljenja",
    "Select a user or group" : "Izbor imena uporabnika oziroma skupine",
    "Open Team folder" : "Odpri ekipno mapo",
    "Permission denied. User does not have sufficient permissions." : "Pravica zavrnjena. Uporabnik nima dovolj pravic.",
    "Unexpected status from server" : "Nepričakovano stanje strežnika",
    "List of Team folders." : "Spisek ekipnih map",
    "No Team folders yet" : "Ekipne mape še niso pripravljene",
    "Team folders will show up here" : "Ekipne mape se bodo pokazale tukaj",
    "Add group" : "Dodaj skupino",
    "Default" : "Privzeto",
    "Unlimited" : "Neomejeno",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Ali ste prepričani, da želite izbrisati mapo »{folderName}« z vsemi datotekami v njej? Tovrstnega opravila ni mogoče razveljaviti.",
    "Delete \"{folderName}\"?" : "Ali želite izbrisati mapo \"{folderName}\"?",
    "Team folder admin delegation" : "Delegiranje skrbništva ekipnim mapam",
    "They will have access to all Team folders." : "Oni bodo imeli dostop do vseh ekipnih map.",
    "They will only have access to Team folders for which they have advanced permissions." : "Imeli bodo dostop do ekipnih map zakatere imajo omogočene napredne pravice.",
    "Group or team" : "Skupina ali ekipa",
    "Folder name" : "Ime mape",
    "Quota" : "Količinska omejitev",
    "Advanced Permissions" : "Napredna dovoljenja",
    "Previous" : "Predhodna",
    "Next" : "Naslednji",
    "User" : "Uporabnik",
    "Unknown" : "Neznano",
    "Users/groups that can manage" : "Uporabniki/ekipe, ki lahko urejajo",
    "None" : "Brez",
    "No other groups or teams available" : "Ni drugih skupin ali ekip na voljo",
    "No other groups available" : "Ni drugih skupin na voljo",
    "{displayName} (team)" : "{displayName} (ekipa)",
    "Add group or team" : "Dodaj skupino ali ekipo",
    "{size} used" : "V uporabi {size}·",
    "Group folders" : "Skupinske mape",
    "Admin configured folders shared with everyone in a group" : "Skrbniško določene mape v souporabi vseh v skupini",
    "Group folder" : "Skupinska mapa",
    "Open group folder" : "Odpri skupinsko mapo",
    "List of group folders." : "Seznam skupinskih map",
    "No group folders yet" : "Skupinske mape še niso pripravljene",
    "Group folders will show up here" : "Skupinske mape se bodo pokazale tukaj",
    "Group folder admin delegation" : "Delegiranje skrbništva skupinskim mapam",
    "They will have access to all group folders." : "Oni bodo imeli dostop do vseh skupinskih map.",
    "They will only have access to group folders for which they have advanced permissions." : "Imeli bodo dostop do skupinskih map zakatere imajo omogočene napredne pravice."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> groupfolders-v20.1.1.tar.gz: groupfolders/l10n/sl.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Ne moreš odstraniti lastne pravice do branja.",
    "Team folders" : "Ekipne mape",
    "Unset" : "Odstrani izbor",
    "Denied (Inherited permission)" : "Zavrnjeno (podedovano dovoljenje)",
    "Allowed (Inherited permission)" : "Dovoljeno (podedovano dovoljenje)",
    "Denied" : "Zavrnjeno",
    "Allowed" : "Dovoljeno",
    "Access denied" : "Dostop je zavrnjen",
    "Access allowed" : "Dostop dovoljen",
    "Inherit permission" : "Podeduj dovoljenje",
    "Deny" : "Zavrni",
    "Allow" : "Dovoli",
    "Group" : "Skupina",
    "Team" : "Skupina",
    "Team folder" : "Ekipna mapa",
    "Read" : "Branje",
    "Write" : "Zapiši",
    "Create" : "Ustvari",
    "Delete" : "Izbriši",
    "Share" : "Omogoči souporabo",
    "You" : "· Jaz",
    "Remove access rule" : "Odstrani pravilo za dostop",
    "Add advanced permission rule" : "Dodaj napredno pravilo dovoljenja",
    "Select a user or group" : "Izbor imena uporabnika oziroma skupine",
    "Open Team folder" : "Odpri ekipno mapo",
    "Permission denied. User does not have sufficient permissions." : "Pravica zavrnjena. Uporabnik nima dovolj pravic.",
    "Unexpected status from server" : "Nepričakovano stanje strežnika",
    "List of Team folders." : "Spisek ekipnih map",
    "No Team folders yet" : "Ekipne mape še niso pripravljene",
    "Team folders will show up here" : "Ekipne mape se bodo pokazale tukaj",
    "Add group" : "Dodaj skupino",
    "Default" : "Privzeto",
    "Unlimited" : "Neomejeno",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Ali ste prepričani, da želite izbrisati mapo »{folderName}« z vsemi datotekami v njej? Tovrstnega opravila ni mogoče razveljaviti.",
    "Delete \"{folderName}\"?" : "Ali želite izbrisati mapo \"{folderName}\"?",
    "Team folder admin delegation" : "Delegiranje skrbništva ekipnim mapam",
    "They will have access to all Team folders." : "Oni bodo imeli dostop do vseh ekipnih map.",
    "They will only have access to Team folders for which they have advanced permissions." : "Imeli bodo dostop do ekipnih map zakatere imajo omogočene napredne pravice.",
    "Group or team" : "Skupina ali ekipa",
    "Folder name" : "Ime mape",
    "Quota" : "Količinska omejitev",
    "Advanced Permissions" : "Napredna dovoljenja",
    "Previous" : "Predhodna",
    "Next" : "Naslednji",
    "User" : "Uporabnik",
    "Unknown" : "Neznano",
    "Users/groups that can manage" : "Uporabniki/ekipe, ki lahko urejajo",
    "None" : "Brez",
    "No other groups or teams available" : "Ni drugih skupin ali ekip na voljo",
    "No other groups available" : "Ni drugih skupin na voljo",
    "{displayName} (team)" : "{displayName} (ekipa)",
    "Add group or team" : "Dodaj skupino ali ekipo",
    "{size} used" : "V uporabi {size}·",
    "Group folders" : "Skupinske mape",
    "Admin configured folders shared with everyone in a group" : "Skrbniško določene mape v souporabi vseh v skupini",
    "Group folder" : "Skupinska mapa",
    "Open group folder" : "Odpri skupinsko mapo",
    "List of group folders." : "Seznam skupinskih map",
    "No group folders yet" : "Skupinske mape še niso pripravljene",
    "Group folders will show up here" : "Skupinske mape se bodo pokazale tukaj",
    "Group folder admin delegation" : "Delegiranje skrbništva skupinskim mapam",
    "They will have access to all group folders." : "Oni bodo imeli dostop do vseh skupinskih map.",
    "They will only have access to group folders for which they have advanced permissions." : "Imeli bodo dostop do skupinskih map zakatere imajo omogočene napredne pravice.",
    "Admin configured folders shared with everyone in a team" : "Skrbnik je nastavil mape deljene z vsemi v ekipi"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
